=== modified file 'Makefile'
--- Makefile	2008-10-07 18:32:42 +0000
+++ Makefile	2008-10-13 23:29:15 +0000
@@ -180,10 +180,7 @@
 sync_branches: pull_branches scan_branches
 
 bzr_version_info:
-	rm -f bzr-version-info.py bzr-version-info.pyc
-	if which bzr > /dev/null  && test -x `which bzr`; \
-		then PYTHONPATH= bzr version-info --format=python > bzr-version-info.py 2>/dev/null; \
-	fi
+	scripts/update-bzr-version-info.sh
 
 # Run as a daemon - hack using nohup until we move back to using zdaemon
 # properly. We also should really wait until services are running before 

=== added file 'scripts/update-bzr-version-info.sh'
--- scripts/update-bzr-version-info.sh	1970-01-01 00:00:00 +0000
+++ scripts/update-bzr-version-info.sh	2008-10-13 23:29:15 +0000
@@ -0,0 +1,32 @@
+#!/bin/bash
+#
+# Update bzr-version-info.py -- but only if the revision number has
+# changed
+#
+
+if ! which bzr > /dev/null || !  test -x $(which bzr); then
+    echo "No working 'bzr' executable found"
+    exit 1
+fi
+
+newfile=bzr_version_info_${RANDOM}.py
+PYTHONPATH= bzr version-info --format=python > $newfile 2>/dev/null;
+# There's a leading space here that I don't care to trim.. 
+revno=$(python $newfile | grep revision: | cut -d: -f2)
+if ! [ -f bzr_version_info.py ]; then
+    echo "Creating bzr_version_info.py at revno$revno"
+    mv ${newfile} bzr_version_info.py
+else
+    # Here we compare the actual output instead of the contents of the
+    # file because bzr includes a build-date that is actually updated
+    # every time you run bzr version-info.
+    newcontents=$(python $newfile)
+    oldcontents=$(python bzr_version_info.py)
+    if [ "$newcontents" != "$oldcontents" ]; then
+        echo "Updating bzr_version_info.py to revno$revno"
+        mv ${newfile} bzr_version_info.py
+    else
+        echo "Skipping bzr_version_info.py update; already at revno$revno"
+        rm ${newfile}
+    fi
+fi

